Crate garage_api_common

Crate garage_api_common 

Crate for serving a S3 compatible API

Modules

common_error
cors
encoding
Module containing various helpers for encoding
generic_server
helpers
router_macros
signature
xml

Macros

commonErrorDerivative
generateQueryParameters
This macro is used to generate part of the code in this module. It must be called only one, and is useless outside of this module.
router_match
This macro is used to generate very repetitive match {} blocks in this module It is not made to be used anywhere else